@@ -1,7 +1,7 @@
-from hugegraph import PHugeGraph
+from hugegraph.connection import PyHugeGraph
 
 if __name__ == '__main__':
-    client = PHugeGraph("10.21.3.10", "8080", user="admin", pwd="admin", graph="hugegraph")
+    client = PyHugeGraph("127.0.0.1", "8080", user="admin", pwd="admin", graph="hugegraph")
 
     """system"""
     res = client.get_graphinfo()
